@@ -413,9 +413,9 @@ def main():
 	if isdir(src):
 		for f in ('~/.local/share/pavlovadm/pavlovadm.conf', '~/.local/share/pavlovadm/Game.ini', '~/.local/share/pavlovadm/public.ini', '~/.local/share/pavlovadm/BalancingTable.csv'):
 			if not isfile('%s/%s'%(cfgdir, basename(f))):
-				with open(expanduser(f), 'r') as lfh, open('%s/%s'%(cfgdir, basename(f)), 'w+') as gfh:
+				with open(expanduser(f), 'r') as lfh, open(expanduser('~/%s/%s'%(cfgdir, basename(f))), 'w+') as gfh:
 					gfh.write(lfh.read())
-	cfgs = config('%s/%s.conf'%(__me, __me))
+	cfgs = config(expanduser('~/%s/%s.conf'%(__me, __me)))
 
 	pars = ArgumentParser(description=__dsc)
 	pars.add_argument(
